package com.ruoyi.oa.mapper;

import java.util.List;
import com.ruoyi.oa.domain.CmcBrandPayment;

/**
 * cmc品牌项目支付记录Mapper接口
 * 
 * @author cmc
 * @date 2024-04-29
 */
public interface CmcBrandPaymentMapper 
{
    /**
     * 查询cmc品牌项目支付记录
     * 
     * @param brandId cmc品牌项目支付记录主键
     * @return cmc品牌项目支付记录
     */
    public List<CmcBrandPayment> selectCmcBrandPaymentByBrandId(String brandId);

    /**
     * 查询cmc品牌项目支付记录列表
     * 
     * @param cmcBrandPayment cmc品牌项目支付记录
     * @return cmc品牌项目支付记录集合
     */
    public List<CmcBrandPayment> selectCmcBrandPaymentList(CmcBrandPayment cmcBrandPayment);

    /**
     * 新增cmc品牌项目支付记录
     * 
     * @param cmcBrandPayment cmc品牌项目支付记录
     * @return 结果
     */
    public int insertCmcBrandPayment(CmcBrandPayment cmcBrandPayment);

    /**
     * 修改cmc品牌项目支付记录
     * 
     * @param cmcBrandPayment cmc品牌项目支付记录
     * @return 结果
     */
    public int updateCmcBrandPayment(CmcBrandPayment cmcBrandPayment);

    /**
     * 删除cmc品牌项目支付记录
     * 
     * @param brandId cmc品牌项目支付记录主键
     * @return 结果
     */
    public int deleteCmcBrandPaymentByBrandId(String brandId);

    /**
     * 批量删除cmc品牌项目支付记录
     * 
     * @param brandIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCmcBrandPaymentByBrandIds(String[] brandIds);
}
